@@ -60,6 +60,7 @@ options:
                                          [default: True].
     --keep-directories                   Keep directories in the supplied file paths for
                                          the remote filename. [default: False]
+    --no-scanner                         Do not set the scanner field in meta.xml.
 """
 import csv
 import os
@@ -67,6 +68,7 @@ import sys
 import webbrowser
 from copy import deepcopy
 from locale import getpreferredencoding
+from pathlib import Path
 from tempfile import TemporaryFile
 
 from docopt import docopt, printable_usage
@@ -87,6 +89,10 @@ from internetarchive.utils import (
 
 def _upload_files(item, files, upload_kwargs, prev_identifier=None, archive_session=None):
     """Helper function for calling :meth:`Item.upload`"""
+    # Check if the list has any element.
+    if not files:
+        raise FileNotFoundError("No valid file was found. Check your paths.")
+
     responses = []
     if (upload_kwargs['verbose']) and (prev_identifier != item.identifier):
         print(f'{item.identifier}:', file=sys.stderr)
@@ -114,7 +120,7 @@ def _upload_files(item, files, upload_kwargs, prev_identifier=None, archive_sess
     return responses
 
 
-def main(argv, session):
+def main(argv, session):  # noqa: C901
     args = docopt(__doc__, argv=argv)
     ERRORS = False
 
@@ -141,8 +147,8 @@ def main(argv, session):
         '--header': Or(None, And(Use(get_args_dict), dict),
                        error='--header must be formatted as --header="key:value"'),
         '--retries': Use(lambda x: int(x[0]) if x else 0),
-        '--sleep': Use(lambda l: int(l[0]), error='--sleep value must be an integer.'),
-        '--size-hint': Or(Use(lambda l: str(l[0]) if l else None), int, None,
+        '--sleep': Use(lambda lst: int(lst[0]), error='--sleep value must be an integer.'),
+        '--size-hint': Or(Use(lambda lst: str(lst[0]) if lst else None), int, None,
                           error='--size-hint value must be an integer.'),
         '--status-check': bool,
     })
@@ -187,6 +193,7 @@ def main(argv, session):
 
     queue_derive = True if args['--no-derive'] is False else False
     verbose = True if args['--quiet'] is False else False
+    set_scanner = False if args['--no-scanner'] is True else True
 
     if args['--file-metadata']:
         try:
@@ -203,6 +210,7 @@ def main(argv, session):
         'headers': args['--header'],
         'debug': args['--debug'],
         'queue_derive': queue_derive,
+        'set_scanner': set_scanner,
         'verbose': verbose,
         'verify': args['--verify'],
         'checksum': args['--checksum'],
@@ -237,6 +245,10 @@ def main(argv, session):
             local_file.seek(0)
         else:
             local_file = args['<file>']
+            # Properly expand a period to the contents of the current working directory.
+            if '.' in local_file:
+                local_file = [p for p in local_file if p != '.']
+                local_file = os.listdir('.') + local_file
 
         if isinstance(local_file, (list, tuple, set)) and args['--remote-name']:
             local_file = local_file[0]
